%define _qt4_version %(pkg-config --modversion --silence-errors Qt 2>/dev/null || echo 4.7.2)
%define _qt4_prefix %(pkg-config --variable prefix --silence-errors Qt 2>/dev/null || echo %{_libdir}/qt-%{qt4_ver})

%define ENABLE_TESTS -DENABLE_TESTS:BOOL=ON

Name:           avogadro
Summary:        An advanced molecular editor for chemical purposes
Version:        1.0.1
Release:        8%{?_dist_release}

Group:          Applications/Editors
License:        GPLv2
URL:            http://avogadro.openmolecules.net/

Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
# fix FTBFS with SIP 4.11 (Gentoo#335644)
# patch submitted: http://bugs.gentoo.org/attachment.cgi?id=247308 (upstream is
# CCed on the Gentoo bug)
Patch0:         avogadro-1.0.1-sip411.patch
# fix crash with current SIP and Python 2.7 (#642248)
Patch1:         avogadro-1.0.1-pycapsule.patch

BuildRequires:  cmake >= 2.6.0
BuildRequires:  qt4-devel >= 4.5.1
BuildRequires:  qt4-tools
BuildRequires:  eigen2-devel >= 2.0.3
BuildRequires:  openbabel-devel >= 2.2.2
BuildRequires:  libboost-devel >= 1.35
BuildRequires:  libboost-python >= 1.35
BuildRequires:  glew-devel >= 1.5.0
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-utils
BuildRequires:  sip-devel >= 4.11
BuildRequires:  numpy

Requires: %{name}-libs = %{version}-%{release}

%description
An advanced molecular editor designed for 
cross-platform use in computational chemistry,
molecular modeling, bioinformatics, materials science,
and related areas, which offers flexible rendering and
a powerful plugin architecture.


%package libs
Summary: Shared libraries for Avogadro
Summary(ja): Avogadro の共用ライブラリ
Group: System Environment/Libraries
Requires: sip

%description libs
This package contains the shared libraries for the
molecular editor Avogadro.


%package devel
Summary: Development files for Avogadro
Summary(ja): Avogadro の開発用ファイル
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release} 
Requires: qt4-devel = %{_qt4_version}
Requires: eigen2-devel >= 2.0.3
Requires: glew-devel >= 1.5.0

%description devel
This package contains files to develop applications using 
Avogadros libraries.


%prep
%setup -q
%patch0 -p1 -b .sip411
%patch1 -p1 -b .pycapsule

# nuke unpatched copy, use working version included in cmake instead -- Rex
rm -f cmake/modules/FindPythonLibs.cmake


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
cmake -Wno-dev \
    -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
    -DBIN_INSTALL_DIR:PATH=bin \
    -DLIB_INSTALL_DIR:PATH=%{_lib} \
    -DENABLE_GLSL:BOOL=ON \
    -DENABLE_PYTHON:BOOL=ON \
    %{?ENABLE_TESTS} ..
popd
make %{?_smp_mflags} -C %{_target_platform}


%install
rm -rf $RPM_BUILD_ROOT
make install/fast DESTDIR=$RPM_BUILD_ROOT -C %{_target_platform}


%check
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/avogadro.desktop
# all of these currently require an active X session, so will fail
# in mock
%{?ENABLE_TESTS:make test -C %{_target_platform} ||:}


%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING
%{_bindir}/avogadro
%{_bindir}/avopkg
# TODO: %lang'ify stuff under %%{_datadir}/avogadro/i18n/
%{_datadir}/avogadro/
%{_datadir}/pixmaps/avogadro-icon.png
%{_datadir}/applications/avogadro.desktop
%{_mandir}/man1/avogadro.1*
%{_mandir}/man1/avopkg.1*

%files devel
%defattr(-,root,root,-)
%{_includedir}/avogadro/
%{_libdir}/libavogadro.so
%{_libdir}/avogadro/*.cmake
%{_libdir}/avogadro/1_0/*.cmake
# these look like dups of system copies?, take a closer look and/or ask upstream -- Rex
%{_libdir}/avogadro/1_0/cmake/
%{_qt4_prefix}/mkspecs/features/avogadro.prf

%files libs
%defattr(-,root,root,-)
%{python_sitelib}/Avogadro.so
%{_datadir}/libavogadro/
%{_libdir}/libavogadro.so.1*
%dir %{_libdir}/avogadro/
%dir %{_libdir}/avogadro/1_0/
%{_libdir}/avogadro/1_0/colors/
%{_libdir}/avogadro/1_0/extensions/
%{_libdir}/avogadro/1_0/engines/
%{_libdir}/avogadro/1_0/tools/


%changelog
* Wed Mar  9 2011 Ryoichi INAGAKI <ryo1@bc.wakwak.com> - 1.0.1-8
- rebuilt with qt4-4.7.2
- BR: qt4-tools instead of qt4-designer

* Sun Feb 27 2011 Ryoichi INAGAKI <ryo1@bc.wakwak.com> - 1.0.1-7
- added BR: libboost-python
- added R: glew-devel, eigen2-devel to devel package

* Wed Feb 23 2011 Ryoichi INAGAKI <ryo1@bc.wakwak.com> - 1.0.1-6
- rebuilt with qt4-4.7.1
- added Patch0 and 1 from Fedora

* Tue Jan 18 2011 Shu KONNO <owa@bg.wakwak.com> - 1.0.1-5
- rebuilt with libboost-1.45.0

* Fri Aug 20 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> - 1.0.1-4
- Initial build for Vine Linux

* Wed Aug 04 2010 Rahul Sundaram <sundaram@fedoraproject.org> - 1.0.1-3
- Rebuild for Boost soname bump
- Update to match current guidelines

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon May 24 2010 Rex Dieter <rdieter@fedoraproject.org> - 1.0.1-1
- avogadro-1.0.1
- -devel: move cmake-related files here
- -devel: Req: qt4-devel
- %%files: track lib sonames
- %%check section

* Wed Feb 10 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.0-6
- reenable plugin builds and libs subpackage
- fix their build with sip 4.10

* Fri Jan 08 2010 Sebastian Dziallas <sebastian@when.com> - 1.0.0-5
- disable plugin builds and libs subpackage

* Thu Jan 07 2010 Rex Dieter <rdieter@fedoraproject.org> - 1.0.0-4
- rebuild (sip)

* Mon Nov 23 2009 Rex Dieter <rdieter@fedoraproject.org> - 1.0.0-3 
- rebuild (for qt-4.6.0-rc1, f13+)

* Mon Nov 16 2009 Rex Dieter <rdieter@fedoraproject.org> - 1.0.0-2 
- -libs: Requires: sip-api(%%_sip_api_major) >= %%_sip_api (#538124)
- Requires: %%{name}-libs ...

* Thu Oct 29 2009 Sebastian Dziallas <sebastian@when.com> 1.0.0-1
- update to new upstream release

* Tue Oct 20 2009 Rex Dieter <rdieter@fedoraproject.org> 0.9.8-3 
- rebuild (eigen2)

* Sat Sep 26 2009 Sebastian Dziallas <sebastian@when.com> 0.9.8-2
- fix typo in file list

* Sat Sep 26 2009 Sebastian Dziallas <sebastian@when.com> 0.9.8-1
- update to new upstream release
- enable python and glsl support again

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Jun 06 2009 Sebastian Dziallas <sebastian@when.com> 0.9.6-1
- new upstream release to fix issue with qt 4.5.0 and earlier

* Wed Jun 03 2009 Sebastian Dziallas <sebastian@when.com> 0.9.5-3
- remove remaining python parts
- fix files section finally

* Wed Jun 03 2009 Sebastian Dziallas <sebastian@when.com> 0.9.5-2
- disable python and glsl for now
- fix files section

* Wed Jun 03 2009 Sebastian Dziallas <sebastian@when.com> 0.9.5-1
- update to new release

* Tue May 12 2009 Sebastian Dziallas <sebastian@when.com> 0.9.4-1
- update to new release

* Fri Apr 10 2009 Sebastian Dziallas <sebastian@when.com> 0.9.3-1
- update to new release

* Sat Mar 21 2009 Sebastian Dziallas <sebastian@when.com> 0.9.2-2
- get desktop file properly installed

* Sat Mar 14 2009 Sebastian Dziallas <sebastian@when.com> 0.9.2-1
- update to new release

* Wed Feb 25 2009 Sebastian Dziallas <sebastian@when.com> 0.9.1-1
- update to new release

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jan 22 2009 Sebastian Dziallas <sebastian@when.com> 0.9.0-1
- update to new release

* Sun Sep 14 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-6
- add handbook to docs

* Sun Sep 14 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-5
- add build requirements and fix group names

* Wed Aug 13 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-4
- fix typos

* Sat Aug  9 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-3
- reorganize spec file

* Sat Aug  9 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-2
- rename shared library package and structure spec file

* Sun Aug  3 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-1
- initial pacakging release based on PackMan release
