%define dbver_rel 4.0
%define dbver_snap 20110405
%define enginever 4.0.7
%define filtersver 4.0.7

Summary: Foomatic printer database.
Name:		foomatic
Version:	%{enginever}
Release: 	1%{?_dist_release}
License:	GPL
Group: System Environment/Libraries

Vendor: Project Vine
Distribution: Vine Linux
Packager: tomop, daisuke, machino

Source0: http://www.linuxprinting.org/download/foomatic/foomatic-db-engine-%{enginever}.tar.gz
Source1: http://www.linuxprinting.org/download/foomatic/foomatic-filters-%{filtersver}.tar.gz
Source2: http://www.linuxprinting.org/download/foomatic/foomatic-db-%{dbver_rel}-%{dbver_snap}.tar.gz

# Use libdir.
Patch1: foomatic-filters-libdir.patch
Patch2: foomatic-db-engine-libdir.patch

# Handle non-UTF-8 encodings in imported PPD files.
Patch15: foomatic-bad-utf8.patch

Url:		http://www.linuxprinting.org
Requires:	perl >= 5.12.3
Requires:	%(eval `perl -V:version`; echo "perl(:MODULE_COMPAT_$version)")
Requires:	hpijs
BuildRequires:	perl >= 5.12.3
BuildRequires:	libxml2-devel
BuildRequires:	ghostscript-devel
BuildRequires:	autoconf, automake
BuildRequires:	mpage
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
Provides:	perl(Foomatic::GrovePath)
# For 'rm' and '/sbin/service' in post
Requires(pre): 	fileutils initscripts
Obsoletes: foomatic-db < 4.0.0
Obsoletes: foomatic-ppd < 4.0.0
Obsoletes: foomatic-ppd-gimp-print < 4.0.0
Obsoletes: foomatic-ppd-gimp-print-ijs < 4.0.0
Obsoletes: foomatic-ppd-omni < 4.0.0

# We need ghostscript to have the gimp-print-4.2.0 driver, and hpijs 1.1.
Conflicts: ghostscript < 7.05

%description
Foomatic is a comprehensive, spooler-independent database of printers,
printer drivers, and driver descriptions. It contains utilities to
generate driver description files and printer queues for CUPS, LPD,
LPRng, and PDQ using the database. There is also the possibility to
read the PJL options out of PJL-capable laser printers and take them
into account at the driver description file generation.

There are spooler-independent command line interfaces to manipulate
queues (foomatic-configure) and to print files/manipulate jobs
(foomatic printjob).

The site http://www.linuxprinting.org/ is based on this database.

%prep
%setup -q  -c -a 1 -a 2

pushd foomatic-filters-%{filtersver}
%patch1 -p1 -b .libdir
popd

pushd foomatic-db-engine-%{enginever}
chmod a+x mkinstalldirs
%patch2 -p1 -b .libdir
%patch15 -p1
popd

pushd foomatic-db-%{dbver_snap}

cd db/source

# For gutenprint printers, use gutenprint-ijs-simplified.5.2.
perl -pi -e 's,>gutenprint<,>gutenprint-ijs-simplified.5.2<,' printer/*.xml

# Remove references to foo2zjs, foo2oak, foo2hp and foo2qpdl (bug #208851).
# Also foo2lava, foo2kyo, foo2xqx (bug #438319).
for x in zjs oak hp qpdl lava kyo xqx
do
  find printer -name '*.xml' |xargs grep -l "<driver>foo2${x}"|xargs rm -vf
  rm -f driver/foo2${x}.xml opt/foo2${x}-*
done
# Same for m2300w/m2400w
find printer -name '*.xml' |xargs grep -l '<driver>m2[34]00w<'|xargs rm -vf
rm -f driver/m2300w.xml driver/m2400w.xml opt/m2300w-*
# Same for all these.
for x in drv_x125 ml85p pbm2lwxl pbmtozjs bjc800j
do
  find printer -name '*.xml' |xargs grep -l "<driver>${x}</driver>"|xargs rm -vf
  rm -vf driver/${x}.xml opt/${x}-*
done

popd

%build
export LIB_CUPS=%{_libdir}/cups
export CUPS_BACKENDS=%{_libdir}/cups/backend
export CUPS_FILTERS=%{_libdir}/cups/filter
export CUPS_PPDS=%{_datadir}/cups/model

pushd foomatic-filters-%{filtersver}
%configure
make %{_smp_mflags} PREFIX=%{_prefix} CFLAGS="$RPM_OPT_FLAGS" \
	INSTALLDIRS=vendor
popd

pushd foomatic-db-engine-%{enginever}
%configure --disable-xmltest
make %{_smp_mflags} PREFIX=%{_prefix} CFLAGS="$RPM_OPT_FLAGS" \
	INSTALLDIRS=vendor defaults
make %{_smp_mflags} PREFIX=%{_prefix} CFLAGS="$RPM_OPT_FLAGS" \
	INSTALLDIRS=vendor
popd

pushd foomatic-db-%{dbver_snap}
%configure
make %{_smp_mflags} PREFIX=%{_prefix} CFLAGS="$RPM_OPT_FLAGS" \
	INSTALLDIRS=vendor
popd

%install
rm -rf %{buildroot}

pushd foomatic-filters-%{filtersver}
eval `perl '-V:installvendorlib' '-V:installvendorarch'`
mkdir -p %{buildroot}/$installvendorlib


echo %{buildroot}

make	DESTDIR=%{buildroot} PREFIX=%{_prefix} \
	INSTALLDIRS=vendor \
	INSTALLVENDORLIB=$installvendorlib \
	INSTALLVENDORARCH=$installvendorarch \
	install-main install-cups
popd

pushd foomatic-db-engine-%{enginever}
make    DESTDIR=%buildroot PREFIX=%{_prefix} \
	INSTALLDIRS=vendor \
	INSTALLVENDORLIB=$installvendorlib \
	INSTALLVENDORARCH=$installvendorarch \
        install
popd

pushd foomatic-db-%{dbver_snap}
make    DESTDIR=%buildroot PREFIX=%{_prefix} \
	INSTALLDIRS=vendor \
	INSTALLVENDORLIB=$installvendorlib \
	INSTALLVENDORARCH=$installvendorarch \
        install
popd

# Remove ghostscript UPP drivers that are gone in 7.07
rm -f %buildroot%{_datadir}/foomatic/db/source/driver/{bjc6000a1,PM760p,PM820p,s400a1,sharp,Stc670pl,Stc670p,Stc680p,Stc760p,Stc777p,Stp720p,Stp870p}.upp.xml

# Remove drivers with no command line.
pushd foomatic-db-engine-%{enginever}
perl -Ilib ./foomatic-cleanupdrivers %buildroot%{_datadir}/foomatic
popd

# Update any old-style printer IDs still left around.
echo '#!/usr/bin/perl -pi' > convert-printerids.pl
sed -e 's|^\(.*\) \(.*\)$|s,printer/\1,printer/\2,g;|' \
	%{buildroot}%{_datadir}/foomatic/db/oldprinterids \
	>> convert-printerids.pl
chmod a+x convert-printerids.pl
./convert-printerids.pl %{buildroot}%{_datadir}/foomatic/db/source/{opt,driver}/*.xml
find %{buildroot}%{_datadir}/foomatic/db/source/ -type f | xargs chmod 0644

# Use relative, not absolute, symlink for CUPS filter.
ln -sf ../../../bin/foomatic-rip %{buildroot}%{_libdir}/cups/filter/foomatic-rip

mkdir %{buildroot}%{_datadir}/foomatic/db/source/PPD/Custom
mkdir -p %{buildroot}%{_var}/cache/foomatic

echo cups > %{buildroot}%{_sysconfdir}/foomatic/defaultspooler

# Remove things we don't ship.
rm -rf	%{buildroot}%{_libdir}/perl5/site_perl \
	%{buildroot}%{_libdir}/ppr \
	%{buildroot}%{_sysconfdir}/foomatic/filter.conf.sample
find %{buildroot} -name .packlist -o -name '*.xml.*' | xargs rm -f


%post
/bin/rm -f /var/cache/foomatic/*

# restart the print server if it is running now
/sbin/service lpd condrestart >/dev/null 2>&1
/sbin/service cups condrestart >/dev/null 2>&1

exit 0

%clean
rm -fr %buildroot $RPM_BUILD_DIR/%{name}

%files
%defattr(-,root,root)
%doc --parents */README */USAGE */ChangeLog
%dir %{_sysconfdir}/foomatic
%config(noreplace) %{_sysconfdir}/foomatic/filter.conf
%config(noreplace) %{_sysconfdir}/foomatic/defaultspooler
%{_bindir}/*
%{_sbindir}/*
%{perl_vendorlib}/Foomatic
%{_libdir}/cups/backend/*
%{_libdir}/cups/driver/*
%{_libdir}/cups/filter/*
%{_datadir}/foomatic
%{_datadir}/cups/model/foomatic-db-ppds
%{_mandir}/*/*
%{_var}/cache/foomatic

%changelog
* Wed Apr 06 2011 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.0.7-1
- new upstream release.
- dropped Source3 (no longer provided by upstream).
- updated Patch2.

* Thu Mar 24 2011 IWAI, Masaharu <iwai@alib.jp> 4.0.1-3
- rebuild with perl 5.12.3

* Fri Jul 24 2009 Kazutaka HARADA <kazutaka@dc4.so-net.ne.jp> 4.0.1-2
- add Requires: hpijs

* Fri May 29 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 4.0.1-1
- new upstream release

* Sun Mar 22 2009 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.0.0-1
- new upstream release.
- applied some patches from Fedora development.
- remove subpackages.

* Fri Sep 12 2008 Shu KONNO <owa@bg.wakwak.com> 3.0.2-1vl5
- applied new versioning policy
- used rpm macros: %%perl_sitelib %%perl_sitearch
- added foomatic-db-engine-3.1-20050411-combo-xml.patch
- added foomatic-db-engine-3.1-20050411-perl-data.patch
- fixed permission of %%{_datadir}/foomatic/db

* Sat Dec 02 2006 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 3.0.2-0vl5
- add BuildRequires: libxml2-devel, mpage, Omni
- use %%{_prefix}/lib/{cups,ppr} instead of %%{_libdir}/{cups,ppr}
- run foomatic-cleanupdrivers, foomatic-compiledb with 'perl -Ilib'
- not create ppd-omni package if omni support is disabled

* Tue Apr 11 2005 Satoshi MACHINO <machino@vinelinux.org> 3.0.2-0vl4
- updated foomatic-db to 20050411
- updated foomatic-db-engine to 3.1-20050411
- updated foomatic-db-hpijs to 1.5-20050411
- updated foomatic-filters to 3.1-20050411

* Wed Jan 12 2005 Satoshi MACHINO <machino@vinelinux.org> 3.0.2-0vl3
- updated foomatic-db to 20050112
- updated foomatic-db-engine to 3.1-20050112
- updated foomatic-db-hpijs to 1.5-20050112

* Tue Dec 21 2004 Satoshi MACHINO <machino@vinelinux.org> 3.0.2-0vl2
- updated foomatic-db to 20041220
- updated foomatic-db-hpijs to 1.5-20041220

* Sun Sep 19 2004 Satoshi MACHINO <machino@vinelinux.org> 3.0.2-0vl1
- updated foomatic-db to 20040919
- updated foomatic-db-engine to 3.0.2
- updated foomatic-db-hpijs to 1.5-20040919
- updated foomatic-filters to 3.0.2

* Wed May 26 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 3.0.1-0vl4
- update foomatic-db to 20040526
- update foomatic-db-hpijs to 1.5-20040526

* Tue May 25 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 3.0.1-0vl3
- sprit foomatic-ppd to ppd,ppd-hpijs,ppd-omni,ppd-gimp-print,
  ppd-gimp-print-ijs
- add Requires: to ppd-* subpackages.

* Thu Apr 15 2004 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 3.0.1-0vl2
- new upstream version
	-- Omni-printers-0.9.1
	-- gimp-print-foomatic-db-4.2.6
- foomatic.spec -> foomatic-vl.spec

* Fri Feb 20 2004 Satoshi MACHINO <machino@vinelinux.org> 3.0.1-0vl1
- new upstream version
	-- foomatic-filters-3.0.1
	-- foomatic-db-engine-3.0.1
	-- foomatic-db-20040219
	-- foomatic-db-hpijs-1.5-20040219

* Mon Jan 26 2004 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl11
- new upstream version
	-- foomatic-filters-3.0.1rc3(bug fix. in configure script)
	-- defined filterver
- dropped patch101

* Sun Jan 25 2004 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl10
- new upstream cvs version(foomatic-3.0.1rc2)
        -- foomatic-db-20040125
        -- foomatic-db-engine-3.0.1rc2
        -- foomatic-db-hpijs-1.5-20040125
        -- foomatic-filters-3.0.1rc2
- added patch101
	-- tests diris null in foomatic-filters-3.0.1rc2

* Fri Jan 23 2004 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl9
- new upstream cvs version
	-- foomatic-db-20040123
	-- foomatic-db-engine-3.0-20040123
	-- foomatic-db-hpijs-1.5-20040123
	-- foomatic-filters-3.0-20040123
- dropped old patches

* Sat Dec 13 2003 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl8
- built on perl-5.8.2

* Tue Nov 11 2003 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl7
- separated foomatic-db package included xml files

* Mon Nov 10 2003 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl6
- added description of ppd sub package

* Sun Nov 09 2003 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl5
- separated foomatic-ppd package included PPD files

* Sun Nov 09 2003 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl4
- new upstream version
	-- foomatic-db-20031109, foomatic-db-engine-3.0-20031109
	-- foomatic-filters-3.0-20031109, foomatic-db-hpijs-1.4-1
- dropped patches
	-- foomatic-filters-path.patch(patch0)
	-- foomatic-2.0.2-fontpath.patch(patch3)
- updated patches
	-- foomatic-filters-3.0-20031109-libdir.patch (patch1)
	-- foomatic-db-engine-3.0-20031109-libdir.patch (patch2)
	-- foomatic-filters-3.0-20031109-vine.patch (patch100)

* Thu Nov 06 2003 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl3
- built on perl-5.8.1
- fixed install section in spec file 

* Sat Aug 30 2003 Tomohiro 'Tomo-p' KATO <tomop@teamgedoh.net> 3.0.0-0vl2
- fix some bugs of foomatic-filters.
A

* Sat Jun 07 2003 Satoshi MACHINO <machino@vinelinux.org> 3.0.0-0vl1
- new upstream version
	-- rewrote spec file
	-- added some patches from rawhide(foomatic-3.0.0-5)
- enable cups support

* Sun Apr 20 2003 Satoshi MACHINO <machino@vinelinux.org> 2.0.2-0vl2
- imported some patches from foomatic-2.0.2-18
	-- added foomatic-2.0.2-psc2210.patch
	-- added foomatic-2.0.2-duplex184.patch

* Sun Mar 02 2003 Satoshi MACHINO <machino@vinelinux.org> 2.0.2-0vl1
- imported foomatic-2.0.2-15
 
* Tue Feb  4 2003 Tim Waugh <twaugh@redhat.com> 2.0.2-15
- Update data-generators to CVS.

* Thu Jan 30 2003 Tim Waugh <twaugh@redhat.com> 2.0.2-14
- Use hpijs, not hpijs-rss (we don't ship the RSS patch now).

* Thu Jan 23 2003 Tim Waugh <twaugh@redhat.com> 2.0.2-13
- Pacify printers that don't understand duplex (bug #82385).

* Wed Jan 22 2003 Tim Powers <timp@redhat.com> 2.0.2-12
- rebuilt

* Thu Jan 21 2003 Tim Waugh <twaugh@redhat.com> 2.0.2-11
- Add autodetect info for HP DeskJet 656C.  It doesn't really do
  IEEE 1284 IDs, but since it's a USB device we can figure out it's
  manufacturer and model anyway.

* Thu Jan  9 2003 Tim Waugh <twaugh@redhat.com> 2.0.2-10
- Set GS_FONTPATH in gs wrapper (bug #81410).

* Sat Jan  4 2003 Jeff Johnson <jbj@redhat.com> 2.0.2-9
- use internal dep generator.

* Sun Dec 15 2002 Tim Waugh <twaugh@redhat.com> 2.0.2-8
- Add several device IDs.

* Sat Dec 14 2002 Tim Waugh <twaugh@redhat.com> 2.0.2-7
- Update Omni printers to 0.7.2.
- No longer need Omni badxml patch.

* Sat Dec 14 2002 Tim Powers <timp@redhat.com> 2.0.2-6
- don't use rpms internal dep generator

* Fri Dec  6 2002 Tim Waugh <twaugh@redhat.com> 2.0.2-5
- Omni XML wasn't well-formed.

* Wed Nov 20 2002 Tim Waugh <twaugh@redhat.com> 2.0.2-4
- Update gimp-print data.
- Add 'generic postscript' model.

* Mon Nov 11 2002 Tim Waugh <twaugh@redhat.com> 2.0.2-3
- Update Omni printers to 0.7.1.

* Tue Oct 22 2002 Tim Waugh <twaugh@redhat.com> 2.0.2-2
- Fix file manifest for perl modules.
- Add autodetect information for HP DeskJet 990C.

* Mon Oct 21 2002 Tim Waugh <twaugh@redhat.com> 2.0.2-1
- 2.0.2.
- No longer need 67973, 970c patches.
- Remove cups-drivers-* packages (no longer needed).
- Remove files not shipped.  Ship filter.conf.
- Conditionally restart cups.
- Use libdir.
- Don't put things in site_perl; use vendor_perl instead (bug #73528).

* Fri Aug  9 2002 Tim Waugh <twaugh@redhat.com> 1.9-1.20020617.6
- Fix autodetect information for HPDJ970C.

* Thu Aug  8 2002 Tim Waugh <twaugh@redhat.com> 1.9-1.20020617.5
- For gimp-print, use the Ghostscript stp driver in preference to the
  IJS interface.

* Thu Jul 25 2002 Tim Waugh <twaugh@redhat.com> 1.9-1.20020617.4
- Quieten scriptlets.

* Fri Jul  5 2002 Tim Waugh <twaugh@redhat.com> 1.9-1.20020617.3
- Fix autodetect information for HPLJ2100/2100M.

* Fri Jun 21 2002 Tim Powers <timp@redhat.com> 1.9-1.20020617.2
- automated rebuild

* Wed Jun 19 2002 Tim Waugh <twaugh@redhat.com> 1.9-0.20020617.2
- Omni 0.7.0 printers.

* Mon Jun 17 2002 Tim Waugh <twaugh@redhat.com> 1.9-0.20020617.1
- Update to CVS.
- Remove some more explicit perl dependencies that are picked up
  automatically.

* Wed May 29 2002 Tim Waugh <twaugh@redhat.com> 1.9-0.20020517.3
- Remove explicit perl-Storable dependency; it should be perl(Storable),
  and that is picked up automatically.

* Tue May 28 2002 Tim Waugh <twaugh@redhat.com> 1.9-0.20020517.2
- Fix release number.
- Drop gen-ppds from the file manifest---use foomatic-compiledb instead
  (bug #63622).

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 23 2002 Tim Waugh <twaugh@redhat.com> 1.9-0.20020517.1
- Remove ghostscript UPP drivers that are gone in 7.05.

* Sat May 18 2002 Tim Waugh <twaugh@redhat.com> 1.9-0.20020517.0.1
- Update to CVS.
- Updated requirements.
- Updated path and libdir patches.
- Drop hpijs 1.0.2 patch.
- foomatic-datafile has moved to %%{_bindir}.
- Update gimp-print data to 4.2.1.
- Update Omni printer data to 0.6.1.

* Thu Apr  4 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020313.3
- Fix the hpijs option data too (bug #62587).

* Wed Apr  3 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020313.2
- Back off to 1.0.2 for hpijs driver data (bug #62587).

* Thu Mar 14 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020313.1
- Update to CVS.

* Wed Mar  6 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020306.1
- Update to CVS.
- Patches no longer needed: conffile, sys, cachedir, fd0.
- Adapted path patch.

* Tue Mar  5 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.10
- Fix bug #58319.
- Drop dbg patch.

* Mon Feb 25 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.9
- Fix file lists.

* Mon Feb 25 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.8
- Fix %post scriplet bug (bug #59942).

* Thu Feb 21 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.7
- Rebuild in new environment.

* Wed Feb 13 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.6
- Merge cups-drivers.  No epoch needed.
- Require perl-URI.

* Wed Feb 06 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.5
- Cache fix.

* Mon Feb  4 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.4
- Don't ship backup files.

* Mon Feb  4 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.3
- Rebuild to pick up new perl installsitelib.

* Thu Jan 31 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.2
- Fix a thinko in DB.pl.

* Wed Jan 30 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020130.1
- Update to CVS.
- No longer need the cachedir patch.
- Fix config file path.
- Look in /usr/local/bin last, not first, in lpdomatic (bug #57915).

* Tue Jan 29 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020129.1
- Update to CVS.
- Patches no longer needed: prepend, fd3.
- Use RPM_OPT_FLAGS.
- Allow non-root users to use foomatic-datafile (bug #58956).

* Sat Jan 26 2002 Jeff Johnson <jbj@redhat.com> 1.1-0.20020124.2
- added Provides: perl(Foomatic::GrovePath)

* Thu Jan 24 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20020124.1
- Update to CVS.
- Updated Omni printers to those in Omni 0.5.1.
- Updated patches: prepend, fd3.
- Patches no longer needed: utf8, lpdomatic.
- Added gimp-print (formerly stp) foomatic db info, and removed the old
  stp.xml file.
- Conflict with ghostscript if it doesn't have gimp-print-4.2.0 yet.

* Fri Jan 18 2002 Tim Waugh <twaugh@redhat.com> 1.1-0.20011218.2
- REALLY fix PCL fixup code (bug #55909, others).
- PreReq fileutils, initscripts (bug #56984).
- Fix prepends in lpdomatic (bug #57371).
- Run foomatic-cleanupdrivers during install, to remove driver entries
  with no command line.
- Put lpdomatic in /usr/sbin again.
- Fix foomatic-gswrapper's file descriptor manipulations (bug #56871).

* Mon Dec 17 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011218.1
- re-imported from upstream to fix some perl fixup code on pcl printers.

* Mon Dec 17 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011217.2
- fix the rest of the quoting issues with foomatic-combo-xml with the patch
- foomatic-1.1-20011217-quotes.patch. This has been sent upstream.

* Mon Dec 17 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011217.1
- respin to pull in latest foomatic database, fixes:
-	properly use the cache in relation to foomatic-combo-xml's output
-	fix _some_ of the quoting issues with calling foomatic-combo-xml

* Thu Dec  5 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011205.1
- respin to pull in latest foomatic database, fixes:
-	droping half of a large job
-	-Mutf8 added to the upstream filters
-	miscelaneous printer db updates

* Mon Nov 29 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011018.8
- added Requires: fileutils for the 'rm' in post

* Mon Nov 26 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011018.7
- /var/chache => /var/cache, doh!

* Fri Nov 16 2001 Nalin Dahyabhai <nalin@redhat.com> 1.1-0.20011018.6
- fix %%post scriptlet

* Tue Nov 13 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011018.5
- changed the patch to use the -Mutf8 command line option,
- and to restart the printserver, after rebuilding the settings.

* Fri Nov  9 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011018.4
- grumble. Some drivers use inline perl scripts, and need the 'use utf8;'
- pragma. Without it, they break on _some_ of their options.

* Wed Oct 31 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011018.3
- patched lpdomatic to prepend PostScript options in the _right_ place.

* Thu Oct 25 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011018.2
- zap the foomatic cache on install

* Thu Oct 18 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011018.1
- rolled to pull in latest information.
- added Omni printers to the printer list.

* Fri Oct 05 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011005.1
- rolled to pull in an ia64 fix to foomatic-combo-xml.c

* Mon Oct 01 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20011001.1
- rolled to pull in foomatic fixes to foomatic-combo-xml.c

* Wed Sep 05 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20010905.1
- upgraded to latest foomatic, we now have fast overview generation!
- this means that there is no prebuilt overview file.

* Tue Aug 28 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20010828.1
- WOW! The latest foomatic uses Till Kamppeter's C based combo compiler.
- It is now fast enough that there is no real benifit to precompiling.
- NOTE: this forces the package to stop being noarched.

* Mon Aug 27 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20010827.1
- fresh pull, maybe it fixes the build errors.

* Sat Aug 25 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20010825.1
- did a fresh database pull, which contains the old japanese printers as well.
- removed japanese hack.

* Tue Aug 14 2001 Akira TAGOH <tagoh@redhat.com> 1.1-0.20010717.5
- Add Japanese printer entry.

* Mon Aug  6 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20010717.4
- move the cache back to /var, sigh.

* Mon Jul 23 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20010717.2
- made foomatic pre-compute its db

* Thu Jul 18 2001 Crutcher Dunnavant <crutcher@redhat.com> 1.1-0.20010717.1
- imported from mandrake.

* Tue Jul 17 2001 Till Kamppeter <till@mandrakesoft.com> 1.1-0.20010717mdk
- Added job listing/removal/manipulation and queue control to
  foomatic-printjob
- Support for printing multiple copies with PDQ

* Fri Jul 14 2001 Till Kamppeter <till@mandrakesoft.com> 1.1-0.20010714mdk
- Included the cupsomatic filter script
- When a queue is set up, default options can be set now
- Help messages of foomatic-configure and foomatic-printjob cleaned up.

* Fri Jul 13 2001 Till Kamppeter <till@mandrakesoft.com> 1.1-0.20010713mdk
- Many bugfixes in "foomatic-printjob".
- "foomatic-configure" adds the Foomatic config file directory automatically
  to the search paths of PDQ.
- Printing a help page under PDQ was broken.

* Thu Jul 12 2001 Stefan van der Eijk <stefan@eijk.nu> 1.1-0.20010712mdk
- BuildRequires:	perl-devel

* Wed Jul 11 2001 Till Kamppeter <till@mandrakesoft.com> 1.1-0.20010711mdk
- initial release.
- Deleted the obsolete drivers "stp", "cZ11", and "hpdj".
- Patch applied which flushes the memory cache regularly, otherwise
  foomatic-configure would hang when the Foomatic data of GIMP-Print is
  installed. 
